@@ -12,19 +12,40 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from openstack import connection
+import logging
+
 from osc_lib import utils
 
+LOG = logging.getLogger(__name__)
 
-DEFAULT_HA_API_VERSION = '1'
+DEFAULT_HA_API_VERSION = '1.1'
 API_VERSION_OPTION = 'os_ha_api_version'
 API_NAME = 'ha'
 
+SUPPORTED_VERSIONS = [
+    '1',
+    '1.0',
+    '1.1'
+]
+
+API_VERSIONS = {v: 'masakariclient.v1.client.Client'
+                for v in SUPPORTED_VERSIONS}
+
 
 def make_client(instance):
-    """Returns a ha proxy"""
-    conn = connection.Connection(session=instance.session)
-    return conn.instance_ha
+    """Returns a instance_ha proxy"""
+    version = instance._api_version[API_NAME]
+    masakari_client = utils.get_client_class(
+        API_NAME,
+        version,
+        API_VERSIONS)
+
+    LOG.debug('Instantiating masakari service client: %s', masakari_client)
+    client = masakari_client(session=instance.session,
+                             interface=instance.interface,
+                             region_name=instance.region_name,
+                             api_version=instance._api_version[API_NAME])
+    return client.service
 
 
 def build_option_parser(parser):
