@@ -17,7 +17,7 @@ test_masakariclient
 
 Tests for `masakariclient` module.
 """
-import mock
+from unittest import mock
 
 from keystoneauth1.identity.generic import password as ks_password
 from keystoneauth1 import session as ks_session
@@ -59,13 +59,17 @@ class TestV1Client(base.TestCase):
         fake_user_domain_id = 'fake_user_domain_id'
         fake_project_name = 'fake_project_name'
         fake_project_domain_id = 'fake_project_domain_id'
+        fake_interface = 'fake_interface'
+        fake_region_name = 'fake_region_name'
 
         res = mc.Client(auth_url=fake_auth_url,
                         username=fake_username,
                         password=fake_password,
                         user_domain_id=fake_user_domain_id,
                         project_name=fake_project_name,
-                        project_domain_id=fake_project_domain_id)
+                        project_domain_id=fake_project_domain_id,
+                        interface=fake_interface,
+                        region_name=fake_region_name)
 
         self.assertEqual(self.conn.instance_ha, res.service)
         mock_password.assert_called_once_with(
@@ -76,4 +80,7 @@ class TestV1Client(base.TestCase):
             project_name=fake_project_name,
             project_domain_id=fake_project_domain_id)
         mock_session.assert_called_once_with(auth=self.auth)
-        mock_connection.assert_called_once_with(session=self.session)
+        mock_connection.assert_called_once_with(
+            session=self.session, interface=fake_interface,
+            region_name=fake_region_name,
+            ha_api_version=None)
